from setuptools import setup, find_packages

setup(
    name='utils_huna',
    packages=find_packages(),
    version='0.1.5',
    description='HUNA helper functions',
    author='Huna',
    license='',
)
